@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
 import socket
 import time
 from unittest import mock
@@ -19,7 +20,6 @@ from unittest import mock
 from ironic_lib import exception as lib_exc
 from oslo_concurrency import processutils
 from oslo_config import cfg
-from oslo_serialization import jsonutils
 import pkg_resources
 from stevedore import extension
 
@@ -192,8 +192,8 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
         # object.
         a_encoded = self.encoder.encode(a)
         b_encoded = self.encoder.encode(b)
-        self.assertEqual(jsonutils.loads(a_encoded),
-                         jsonutils.loads(b_encoded))
+        self.assertEqual(json.loads(a_encoded),
+                         json.loads(b_encoded))
 
     def test_get_status(self):
         started_at = time.time()
@@ -230,7 +230,8 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
                 'uuid': 'deadbeef-dabb-ad00-b105-f00d00bab10c'
             },
             'config': {
-                'heartbeat_timeout': 300
+                'heartbeat_timeout': 300,
+                'agent_md5_checksum_enable': False
             }
         }
 
@@ -246,6 +247,7 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
                           mock.call('wait_for_disks')],
                          mock_dispatch.call_args_list)
         self.agent.heartbeater.start.assert_called_once_with()
+        self.assertFalse(CONF.md5_enabled)
 
     @mock.patch(
         'ironic_python_agent.hardware_managers.cna._detect_cna_card',
@@ -259,7 +261,7 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
                           mock_wait, mock_dispatch):
         CONF.set_override('inspection_callback_url', '')
         CONF.set_override('listen_tls', True)
-
+        CONF.set_override('md5_enabled', False)
         wsgi_server = mock_wsgi.return_value
 
         def set_serve_api():
@@ -273,7 +275,8 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
                 'uuid': 'deadbeef-dabb-ad00-b105-f00d00bab10c'
             },
             'config': {
-                'heartbeat_timeout': 300
+                'heartbeat_timeout': 300,
+                'agent_md5_checksum_enable': True
             }
         }
 
@@ -289,6 +292,7 @@ class TestBaseAgent(ironic_agent_base.IronicAgentTest):
                           mock.call('wait_for_disks')],
                          mock_dispatch.call_args_list)
         self.agent.heartbeater.start.assert_called_once_with()
+        self.assertTrue(CONF.md5_enabled)
 
     @mock.patch('ironic_lib.mdns.get_endpoint', autospec=True)
     @mock.patch(
